EstadoLicencia class
Constructors
- EstadoLicencia(String descripcion, bool APIKeyValida, bool lecturaDGHabilitada, bool autenticacionHabilitada, bool firmaHabilitada)
- EstadoLicencia.fromJson(Map? json)
Properties
- APIKeyValida ↔ bool
-
getter/setter pair
- autenticacionHabilitada ↔ bool
-
getter/setter pair
- descripcion ↔ String
-
getter/setter pair
- firmaHabilitada ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lecturaDGHabilitada ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited